@@ -3,6 +3,8 @@ context("maturity")
 test_that('returns a data.frame with correct sciname', 
           {
             needs_api()
-            expect_true("Epinephelus morio" %in% maturity("Epinephelus morio")$sciname)
+            expect_true("Epinephelus morio" %in% 
+                          maturity("Epinephelus morio")$Species)
           }
-          )
\ No newline at end of file
+          )
+
